==> aroundme_0_7_4.zip: aroundme_0_7_4/aroundme/components/core/template/barnraiser_01/statistics.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_statistical_summary']; ?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php if (isset($statistics)) { ?>
				<?php echo $lang['txt_online_now']; echo $statistics['total_online_users']; ?><br />
				<?php echo $lang['txt_total_users']; echo $statistics['total_users']; ?><br />
				<?php } ?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_people_by_location']; ?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_people_by_location']; ?><br />
				<?php if (isset($charts['people_by_location'])) { ?>
						<br />
						<img src="get_file.php?file=<?php echo $charts['people_by_location']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
	
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_24_hour_activity']; ?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_24_hour_activity']; ?><br />
				<?php if (isset($charts['latest_activity'])) { ?>
						<br />
						<img src="get_file.php?file=<?php echo $charts['latest_activity']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_30_day_activity']; ?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_30_day_activity']; ?><br />
				<?php if (isset($charts['30_day_activity'])) { ?>
				<br />				
				<img src="get_file.php?file=<?php echo $charts['30_day_activity']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_total_hourly_activity']; ?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_total_hourly_activity']; ?><br />
				<?php if (isset($charts['24_hour_activity'])) { ?>
					<br />
					<img src="get_file.php?file=<?php echo $charts['24_hour_activity']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
</div>
</form>

==> aroundme_0_7_7.zip: aroundme_0_7_7/aroundme/components/core/template/barnraiser_01/statistics.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_statistical_summary']; ?></h1>
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php if (isset($statistics)) { ?>
				<?php echo $lang['txt_online_now']; echo $statistics['total_online_users']; ?><br />
				<?php echo $lang['txt_total_users']; echo $statistics['total_users']; ?><br />
				<?php } ?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_people_by_location']; ?></h1>
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_people_by_location']; ?><br />
				<?php if (isset($charts['people_by_location'])) { ?>
						<br />
						<img src="get_file.php?file=<?php echo $charts['people_by_location']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
	
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_24_hour_activity']; ?></h1>
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_24_hour_activity']; ?><br />
				<?php if (isset($charts['latest_activity'])) { ?>
					<br />
					<img src="get_file.php?file=<?php echo $charts['latest_activity']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_30_day_activity']; ?></h1>
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_30_day_activity']; ?><br />
				<?php if (isset($charts['30_day_activity'])) { ?>
				<br />				
				<img src="get_file.php?file=<?php echo $charts['30_day_activity']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_total_hourly_activity']; ?></h1>
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_total_hourly_activity']; ?><br />
				<?php if (isset($charts['24_hour_activity'])) { ?>
					<br />
					<img src="get_file.php?file=<?php echo $charts['24_hour_activity']; ?>" />
				<?php } ?>
			</div>
		</div>
	</div>
</div>
</form>
